]> diplodocus.org Git - nmh/blobdiff - h/utils.h
Improve POP SASL error handling
[nmh] / h / utils.h
index 13ac94e9531088e863a253692ca98f28b0fe108b..4df5e1565dac062f581b9f77ba166b1a41e53157 100644 (file)
--- a/h/utils.h
+++ b/h/utils.h
@@ -22,9 +22,6 @@ void *mh_xcalloc(size_t nelem, size_t elsize) MALLOC ALLOC_SIZE(1, 2);
 /* Duplicate a NUL-terminated string, exit on failure. */
 char *mh_xstrdup(const char *src) MALLOC;
 
 /* Duplicate a NUL-terminated string, exit on failure. */
 char *mh_xstrdup(const char *src) MALLOC;
 
-/* Call free(3), if ptr isn't NULL. */
-void mh_xfree(void *ptr);
-
 /* Set p to point to newly allocated, uninitialised, memory. */
 #define NEW(p) ((p) = mh_xmalloc(sizeof *(p)))
 
 /* Set p to point to newly allocated, uninitialised, memory. */
 #define NEW(p) ((p) = mh_xmalloc(sizeof *(p)))
 
@@ -89,7 +86,7 @@ bool contains8bit(const char *start, const char *end);
  * See if file has any 8-bit bytes.
  * Arguments include:
  *
  * See if file has any 8-bit bytes.
  * Arguments include:
  *
- * fd          - file descriptor
+ * fd          - file descriptor
  * eightbit    - address of result, will be set to 1 if the file contains
  *                any 8-bit bytes, 0 otherwise.
  *
  * eightbit    - address of result, will be set to 1 if the file contains
  *                any 8-bit bytes, 0 otherwise.
  *
@@ -115,12 +112,10 @@ char *m_strn(int value, unsigned int width);
  * program initialization
  *
  * argv0        - argv[0], presumably the program name
  * program initialization
  *
  * argv0        - argv[0], presumably the program name
* read_context - 0: don't read context
*              - 1: read context, check nmh version, and issue warning message
*                   if non-existent or old
*              - 2: read context, don't check nmh version
  */
  */
-int nmh_init(const char *argv0, int read_context);
+int nmh_init(const char *argv0, bool read_context, bool check_version);
 
 /*
  * Compares prior version of nmh with current version.  Returns 1
@@ -115,12 +112,10 @@ char *m_strn(int value, unsigned int width);
  *
  * argv0        - argv[0], presumably the program name
- * read_context - 0: don't read context
- *              - 1: read context, check nmh version, and issue warning message
- *                   if non-existent or old
- *              - 2: read context, don't check nmh version
+ * read_context - whether to read the context
+ * check_version - if read_context, whether to check the version, and issue warning message if non-existent or old
  */
  */
 
 /*
  * Compares prior version of nmh with current version.  Returns 1